@@ -1,5 +1,5 @@
 # -*- encoding: utf-8 -*-
-# kb v0.1.3
+# kb v0.1.6
 # A knowledge base organizer
 # Copyright © 2020, gnc.
 # See /LICENSE for licensing information.
@@ -16,21 +16,22 @@ __all__ = ()
 import sys
 import argparse
 from kb import __version__
+from typing import Sequence
 
 
-def parse_args(args):
+def parse_args(args: Sequence[str]) -> argparse.Namespace:
     """
     This function parses the arguments which have been passed from the command
     line, these can be easily retrieved for example by using "sys.argv[1:]".
-    It returns a parser object as with argparse.
+    It returns an argparse Namespace object.
 
     Arguments:
     args -- the list of arguments passed from the command line as the sys.argv
             format
 
     Returns:
-    A parser with the provided arguments, which can be used in a
-    simpler format
+    An argparse Namespace object with the provided arguments, which
+    can be used in a simpler format.
     """
     parser = argparse.ArgumentParser(prog='kb',
                                      description='A knowledge base organizer')
@@ -58,12 +59,18 @@ def parse_args(args):
         'update', help='Update artifact properties')
     delete_parser = subparsers.add_parser(
         'delete', help='Delete artifacts')
+    template_parser = subparsers.add_parser(
+        'template', help='Manage templates for artifacts')
     import_parser = subparsers.add_parser(
         'import', help='Import a knowledge base')
     export_parser = subparsers.add_parser(
         'export', help='Export the knowledge base')
     erase_parser = subparsers.add_parser(
         'erase', help='Erase the entire kb knowledge base')
+    sync_parser = subparsers.add_parser(
+        'sync', help='Synchronize the knowledge base with a remote git repository')
+    help_parser = subparsers.add_parser(
+        'help', help='Show help of a particular command')
 
     # add parser
     add_parser.add_argument(
@@ -100,8 +107,24 @@ def parse_args(args):
         help="Status of the artifact",
         type=str,
     )
+    add_parser.add_argument(
+        "--template",
+        help="Template to apply to the artifact",
+        type=str,
+    )
+    add_parser.add_argument(
+        "-b", "--body",
+        help="Body of the artifact",
+        type=str,
+    )
 
     # edit parser
+    edit_parser.add_argument(
+        "nameid",
+        help="Title or ID of the artifact to edit",
+        type=str,
+        nargs="?",
+    )
     edit_parser.add_argument(
         "-i", "--id",
         help="ID of the artifact to edit",
@@ -179,6 +202,13 @@ def parse_args(args):
         dest='verbose',
         default=False,
     )
+    list_parser.add_argument(
+        "-f", "--full-identifier",
+        help="Print results in full-identifier mode",
+        action='store_true',
+        dest='full_identifier',
+        default=False,
+    )
     list_parser.add_argument(
         "-n", "--no-color",
         help="Enabled no-color mode",
@@ -188,6 +218,12 @@ def parse_args(args):
     )
 
     # view parser
+    view_parser.add_argument(
+        "nameid",
+        help="Title or ID of the artifact to view",
+        type=str,
+        nargs="?",
+    )
     view_parser.add_argument(
         "-i", "--id",
         help="ID of the artifact to visualize",
@@ -315,12 +351,23 @@ def parse_args(args):
         default=None,
         type=str,
     )
+    update_parser.add_argument(
+        "--template",
+        help="Template to update",
+        default=None,
+        type=str,
+    )
     update_parser.add_argument(
         "-e", "--edit-content",
-        help="Edit content of the artifact",
+        help="Edit content of the artifact with an editor",
         action="store_true",
         dest="edit_content",
     )
+    update_parser.add_argument(
+        "-b", "--body",
+        help="Update the body of the artifact (erases the current content)",
+        type=str,
+    )
 
     # delete parser
     delete_parser.add_argument(
@@ -342,6 +389,114 @@ def parse_args(args):
         type=str,
     )
 
+    # template parser
+    template_subparsers = template_parser.add_subparsers(help='template commands', dest="template_command")
+    template_subparsers.required = True
+
+    # template subcommands
+    add_template_parser = template_subparsers.add_parser(
+        'add', help='Add a template from a file')
+    edit_template_parser = template_subparsers.add_parser(
+        'edit', help='Edit a template')
+    list_template_parser = template_subparsers.add_parser(
+        'list', help='List all templates')
+    new_template_parser = template_subparsers.add_parser(
+        'new', help='Create a template from starting from an example')
+    delete_template_parser = template_subparsers.add_parser(
+        'delete', help='Delete an existing template')
+    apply_template_parser = template_subparsers.add_parser(
+        'apply', help='Apply a template to an entire set of artifacts')
+
+    add_template_parser.add_argument(
+        "file",
+        help="The template file to add to kb",
+        type=str,
+    )
+    add_template_parser.add_argument(
+        "-t","--title",
+        help="The title to assign to the template added from a file to kb",
+        type=str,
+    )
+    edit_template_parser.add_argument(
+        "template",
+        help="The name of the template to edit",
+        type=str,
+    )
+    list_template_parser.add_argument(
+        "query",
+        help="The name (or part of it) of the template to search for",
+        type=str,
+        nargs='?',
+    )
+    list_template_parser.add_argument(
+        "-n", "--no-color",
+        help="Enabled no-color mode",
+        action='store_true',
+        dest='no_color',
+        default=False,
+    )
+    delete_template_parser.add_argument(
+        "template",
+        help="The name of the template to delete",
+        type=str,
+    )
+    new_template_parser.add_argument(
+        "template",
+        help="The name of the template to create",
+        type=str,
+    )
+
+    apply_template_parser.add_argument(
+        "template",
+        help="The name of the template to apply to the filtered artifacts",
+        type=str,
+    )
+
+    apply_template_parser.add_argument(
+        "-t", "--title",
+        help="Title of the artifacts on which template is applied",
+        type=str,
+    )
+    apply_template_parser.add_argument(
+        "-c", "--category",
+        help="Category of the artifacts on which template is applied",
+        default=None,
+        type=str,
+    )
+    apply_template_parser.add_argument(
+        "-g", "--tags",
+        help="""
+        Tags associates to the artifacts in the form \"tag1;tag2;...;tagN\" where template is applied
+        """,
+        default=None,
+        type=str,
+    )
+    apply_template_parser.add_argument(
+        "-a", "--author",
+        help="Author of the artifacts on which template is applied",
+        default=None,
+        type=str,
+    )
+    apply_template_parser.add_argument(
+        "-s", "--status",
+        help="Status of the artifacts on which template is applied",
+        default=None,
+        type=str,
+    )
+    apply_template_parser.add_argument(
+        "-m","--extended-match",
+        help="""
+        Perform application query not on a strict match,
+        for example:
+        `kb template apply --category cheat -m`
+        will match all artifacts containing in their category \"cheat\",
+        hence \"cheatsheet\", \"mycheats\",\"cheatsheets\" and so on"
+        """,
+        action='store_true',
+        dest='extended_match',
+        default=False,
+    )
+
     # import parser
     import_parser.add_argument(
         "file",
@@ -374,8 +529,38 @@ def parse_args(args):
         default=False,
     )
 
+    # sync parser
+    sync_parser.add_argument(
+        'operation', 
+        help="""Use \"init\" to initialize the remote repo,
+                Use \"push\" to git push (write local -> remote) the knowledge base,
+                Use \"pull\" to git pull (retrieve remote -> local) the remote kb,
+                Use \"info\" to show information about the repository
+             """,
+        choices=['init','push','pull','info'])
+
+    help_parser.add_argument(
+        'cmd',
+        help='Name of command to get help for',
+        nargs='?'
+    )
+
     if len(args) == 0:
         parser.print_help(sys.stderr)
         sys.exit(1)
 
-    return parser.parse_args(args)
+    parsed_args = parser.parse_args()
+    if parsed_args.command == 'help':
+        if not parsed_args.cmd:
+            parser.print_help(sys.stderr)
+        else:
+            try:
+                subparsers.choices[parsed_args.cmd].print_help()
+            except KeyError:
+                print(f'Unknown command name `{parsed_args.cmd}`')
+                print(
+                    f"Valid commands are: {', '.join(subparsers.choices.keys())}"
+                )
+        sys.exit(1)
+
+    return parsed_args
